@@ -55,6 +55,9 @@ if [ -x "/etc/init.d/benno-archive" ]; then
         sleep $i
     done
     echo ""
+
+    VARCHIVE=$(echo "$SYSTEMINFO"|tr -d '()'|grep bennoarchive|cut -d ' ' -f 3)
+    VCORE=$(echo "$SYSTEMINFO" |tr -d '()'|grep bennocore|cut -d ' ' -f 3)
     IPATTERN=$(/bin/echo "$SYSTEMINFO"|grep ImportPattern|perl -p -e 's/ImportPattern:\s+//')
     if [ "${IPATTERN}x" != x ];then
         INBOXDIR=$(dirname "$IPATTERN")
@@ -67,6 +70,8 @@ if [ -x "/etc/init.d/benno-archive" ]; then
       echo "From: benno-archive@sys.benno-mailarchiv.de"
       echo "To: benno-system@sys.benno-mailarchiv.de"
       echo "X-BENNO-System-Recipient: <benno-system@sys.benno-mailarchiv.de>"
+      echo "X-BENNO-Archive-Version: $VARCHIVE"
+      echo "X-BENNO-Core-Version: $VCORE"
       echo "Subject: Benno MailArchiv Installation"
       echo "Date: $INSTALLDATE"
       echo ""
